==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/StorageFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class StorageFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.StorageFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.StorageFluent<A>{
  public StorageFluentImpl() {
  }
  public StorageFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Storage instance) {
    this.withHctl(instance.getHctl()); 
    this.withModel(instance.getModel()); 
    this.withName(instance.getName()); 
    this.withRotational(instance.getRotational()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withSizeBytes(instance.getSizeBytes()); 
    this.withType(instance.getType()); 
    this.withVendor(instance.getVendor()); 
    this.withWwn(instance.getWwn()); 
    this.withWwnVendorExtension(instance.getWwnVendorExtension()); 
    this.withWwnWithExtension(instance.getWwnWithExtension()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String hctl;
  private java.lang.String model;
  private java.lang.String name;
  private java.lang.Boolean rotational;
  private java.lang.String serialNumber;
  private java.lang.Long sizeBytes;
  private java.lang.String type;
  private java.lang.String vendor;
  private java.lang.String wwn;
  private java.lang.String wwnVendorExtension;
  private java.lang.String wwnWithExtension;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHctl() {
    return this.hctl;
  }
  public A withHctl(java.lang.String hctl) {
    this.hctl=hctl; return (A) this;
  }
  public java.lang.Boolean hasHctl() {
    return this.hctl != null;
  }
  
  /**
   * Method is deprecated. use withHctl instead.
   */
  @java.lang.Deprecated
  public A withNewHctl(java.lang.String arg0) {
    return (A)withHctl(new String(arg0));
  }
  public java.lang.String getModel() {
    return this.model;
  }
  public A withModel(java.lang.String model) {
    this.model=model; return (A) this;
  }
  public java.lang.Boolean hasModel() {
    return this.model != null;
  }
  
  /**
   * Method is deprecated. use withModel instead.
   */
  @java.lang.Deprecated
  public A withNewModel(java.lang.String arg0) {
    return (A)withModel(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.Boolean getRotational() {
    return this.rotational;
  }
  public A withRotational(java.lang.Boolean rotational) {
    this.rotational=rotational; return (A) this;
  }
  public java.lang.Boolean hasRotational() {
    return this.rotational != null;
  }
  public java.lang.String getSerialNumber() {
    return this.serialNumber;
  }
  public A withSerialNumber(java.lang.String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  public java.lang.Boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  
  /**
   * Method is deprecated. use withSerialNumber instead.
   */
  @java.lang.Deprecated
  public A withNewSerialNumber(java.lang.String arg0) {
    return (A)withSerialNumber(new String(arg0));
  }
  public java.lang.Long getSizeBytes() {
    return this.sizeBytes;
  }
  public A withSizeBytes(java.lang.Long sizeBytes) {
    this.sizeBytes=sizeBytes; return (A) this;
  }
  public java.lang.Boolean hasSizeBytes() {
    return this.sizeBytes != null;
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public java.lang.String getVendor() {
    return this.vendor;
  }
  public A withVendor(java.lang.String vendor) {
    this.vendor=vendor; return (A) this;
  }
  public java.lang.Boolean hasVendor() {
    return this.vendor != null;
  }
  
  /**
   * Method is deprecated. use withVendor instead.
   */
  @java.lang.Deprecated
  public A withNewVendor(java.lang.String arg0) {
    return (A)withVendor(new String(arg0));
  }
  public java.lang.String getWwn() {
    return this.wwn;
  }
  public A withWwn(java.lang.String wwn) {
    this.wwn=wwn; return (A) this;
  }
  public java.lang.Boolean hasWwn() {
    return this.wwn != null;
  }
  
  /**
   * Method is deprecated. use withWwn instead.
   */
  @java.lang.Deprecated
  public A withNewWwn(java.lang.String arg0) {
    return (A)withWwn(new String(arg0));
  }
  public java.lang.String getWwnVendorExtension() {
    return this.wwnVendorExtension;
  }
  public A withWwnVendorExtension(java.lang.String wwnVendorExtension) {
    this.wwnVendorExtension=wwnVendorExtension; return (A) this;
  }
  public java.lang.Boolean hasWwnVendorExtension() {
    return this.wwnVendorExtension != null;
  }
  
  /**
   * Method is deprecated. use withWwnVendorExtension instead.
   */
  @java.lang.Deprecated
  public A withNewWwnVendorExtension(java.lang.String arg0) {
    return (A)withWwnVendorExtension(new String(arg0));
  }
  public java.lang.String getWwnWithExtension() {
    return this.wwnWithExtension;
  }
  public A withWwnWithExtension(java.lang.String wwnWithExtension) {
    this.wwnWithExtension=wwnWithExtension; return (A) this;
  }
  public java.lang.Boolean hasWwnWithExtension() {
    return this.wwnWithExtension != null;
  }
  
  /**
   * Method is deprecated. use withWwnWithExtension instead.
   */
  @java.lang.Deprecated
  public A withNewWwnWithExtension(java.lang.String arg0) {
    return (A)withWwnWithExtension(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageFluentImpl that = (StorageFluentImpl) o;
    if (hctl != null ? !hctl.equals(that.hctl) :that.hctl != null) return false;
    if (model != null ? !model.equals(that.model) :that.model != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (rotational != null ? !rotational.equals(that.rotational) :that.rotational != null) return false;
    if (serialNumber != null ? !serialNumber.equals(that.serialNumber) :that.serialNumber != null) return false;
    if (sizeBytes != null ? !sizeBytes.equals(that.sizeBytes) :that.sizeBytes != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (vendor != null ? !vendor.equals(that.vendor) :that.vendor != null) return false;
    if (wwn != null ? !wwn.equals(that.wwn) :that.wwn != null) return false;
    if (wwnVendorExtension != null ? !wwnVendorExtension.equals(that.wwnVendorExtension) :that.wwnVendorExtension != null) return false;
    if (wwnWithExtension != null ? !wwnWithExtension.equals(that.wwnWithExtension) :that.wwnWithExtension != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hctl,  model,  name,  rotational,  serialNumber,  sizeBytes,  type,  vendor,  wwn,  wwnVendorExtension,  wwnWithExtension,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.3-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/StorageFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class StorageFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.StorageFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.StorageFluent<A>{
  public StorageFluentImpl() {
  }
  public StorageFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Storage instance) {
    this.withHctl(instance.getHctl()); 
    this.withModel(instance.getModel()); 
    this.withName(instance.getName()); 
    this.withRotational(instance.getRotational()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withSizeBytes(instance.getSizeBytes()); 
    this.withType(instance.getType()); 
    this.withVendor(instance.getVendor()); 
    this.withWwn(instance.getWwn()); 
    this.withWwnVendorExtension(instance.getWwnVendorExtension()); 
    this.withWwnWithExtension(instance.getWwnWithExtension()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String hctl;
  private java.lang.String model;
  private java.lang.String name;
  private java.lang.Boolean rotational;
  private java.lang.String serialNumber;
  private java.lang.Long sizeBytes;
  private java.lang.String type;
  private java.lang.String vendor;
  private java.lang.String wwn;
  private java.lang.String wwnVendorExtension;
  private java.lang.String wwnWithExtension;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHctl() {
    return this.hctl;
  }
  public A withHctl(java.lang.String hctl) {
    this.hctl=hctl; return (A) this;
  }
  public java.lang.Boolean hasHctl() {
    return this.hctl != null;
  }
  
  /**
   * Method is deprecated. use withHctl instead.
   */
  @java.lang.Deprecated
  public A withNewHctl(java.lang.String arg0) {
    return (A)withHctl(new String(arg0));
  }
  public java.lang.String getModel() {
    return this.model;
  }
  public A withModel(java.lang.String model) {
    this.model=model; return (A) this;
  }
  public java.lang.Boolean hasModel() {
    return this.model != null;
  }
  
  /**
   * Method is deprecated. use withModel instead.
   */
  @java.lang.Deprecated
  public A withNewModel(java.lang.String arg0) {
    return (A)withModel(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.Boolean getRotational() {
    return this.rotational;
  }
  public A withRotational(java.lang.Boolean rotational) {
    this.rotational=rotational; return (A) this;
  }
  public java.lang.Boolean hasRotational() {
    return this.rotational != null;
  }
  public java.lang.String getSerialNumber() {
    return this.serialNumber;
  }
  public A withSerialNumber(java.lang.String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  public java.lang.Boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  
  /**
   * Method is deprecated. use withSerialNumber instead.
   */
  @java.lang.Deprecated
  public A withNewSerialNumber(java.lang.String arg0) {
    return (A)withSerialNumber(new String(arg0));
  }
  public java.lang.Long getSizeBytes() {
    return this.sizeBytes;
  }
  public A withSizeBytes(java.lang.Long sizeBytes) {
    this.sizeBytes=sizeBytes; return (A) this;
  }
  public java.lang.Boolean hasSizeBytes() {
    return this.sizeBytes != null;
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public java.lang.String getVendor() {
    return this.vendor;
  }
  public A withVendor(java.lang.String vendor) {
    this.vendor=vendor; return (A) this;
  }
  public java.lang.Boolean hasVendor() {
    return this.vendor != null;
  }
  
  /**
   * Method is deprecated. use withVendor instead.
   */
  @java.lang.Deprecated
  public A withNewVendor(java.lang.String arg0) {
    return (A)withVendor(new String(arg0));
  }
  public java.lang.String getWwn() {
    return this.wwn;
  }
  public A withWwn(java.lang.String wwn) {
    this.wwn=wwn; return (A) this;
  }
  public java.lang.Boolean hasWwn() {
    return this.wwn != null;
  }
  
  /**
   * Method is deprecated. use withWwn instead.
   */
  @java.lang.Deprecated
  public A withNewWwn(java.lang.String arg0) {
    return (A)withWwn(new String(arg0));
  }
  public java.lang.String getWwnVendorExtension() {
    return this.wwnVendorExtension;
  }
  public A withWwnVendorExtension(java.lang.String wwnVendorExtension) {
    this.wwnVendorExtension=wwnVendorExtension; return (A) this;
  }
  public java.lang.Boolean hasWwnVendorExtension() {
    return this.wwnVendorExtension != null;
  }
  
  /**
   * Method is deprecated. use withWwnVendorExtension instead.
   */
  @java.lang.Deprecated
  public A withNewWwnVendorExtension(java.lang.String arg0) {
    return (A)withWwnVendorExtension(new String(arg0));
  }
  public java.lang.String getWwnWithExtension() {
    return this.wwnWithExtension;
  }
  public A withWwnWithExtension(java.lang.String wwnWithExtension) {
    this.wwnWithExtension=wwnWithExtension; return (A) this;
  }
  public java.lang.Boolean hasWwnWithExtension() {
    return this.wwnWithExtension != null;
  }
  
  /**
   * Method is deprecated. use withWwnWithExtension instead.
   */
  @java.lang.Deprecated
  public A withNewWwnWithExtension(java.lang.String arg0) {
    return (A)withWwnWithExtension(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageFluentImpl that = (StorageFluentImpl) o;
    if (hctl != null ? !hctl.equals(that.hctl) :that.hctl != null) return false;
    if (model != null ? !model.equals(that.model) :that.model != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (rotational != null ? !rotational.equals(that.rotational) :that.rotational != null) return false;
    if (serialNumber != null ? !serialNumber.equals(that.serialNumber) :that.serialNumber != null) return false;
    if (sizeBytes != null ? !sizeBytes.equals(that.sizeBytes) :that.sizeBytes != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (vendor != null ? !vendor.equals(that.vendor) :that.vendor != null) return false;
    if (wwn != null ? !wwn.equals(that.wwn) :that.wwn != null) return false;
    if (wwnVendorExtension != null ? !wwnVendorExtension.equals(that.wwnVendorExtension) :that.wwnVendorExtension != null) return false;
    if (wwnWithExtension != null ? !wwnWithExtension.equals(that.wwnWithExtension) :that.wwnWithExtension != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hctl,  model,  name,  rotational,  serialNumber,  sizeBytes,  type,  vendor,  wwn,  wwnVendorExtension,  wwnWithExtension,  additionalProperties,  super.hashCode());
  }
  
}
